==> laaws-repository-service-2.0.10.1-sources.jar: org/lockss/laaws/rs/api/RepoinfoApiDelegate.java <==
package org.lockss.laaws.rs.api;

import org.lockss.laaws.rs.model.RepositoryInfo;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.swagger.annotations.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.multipart.MultipartFile;
import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Optional;

/**
 * A delegate to be called by the {@link RepoinfoApiController}}.
 * Implement this interface with a {@link org.springframework.stereotype.Service} annotated class.
 */

public interface RepoinfoApiDelegate {

    Logger log = LoggerFactory.getLogger(RepoinfoApi.class);

    default Optional<ObjectMapper> getObjectMapper() {
        return Optional.empty();
    }

    default Optional<HttpServletRequest> getRequest() {
        return Optional.empty();
    }

    default Optional<String> getAcceptHeader() {
        return getRequest().map(r -> r.getHeader("Accept"));
    }

    /**
     * @see RepoinfoApi#getRepositoryInformation
     */
    default ResponseEntity<RepositoryInfo> getRepositoryInformation() {
        if(getObjectMapper().isPresent() && getAcceptHeader().isPresent()) {
            if (getAcceptHeader().get().contains("application/json")) {
                try {
                    return new ResponseEntity<>(getObjectMapper().get().readValue("{  \"indexInfo\" : {    \"avail\" : 1,    \"percentUsedString\" : \"percentUsedString\",    \"size\" : 0,    \"name\" : \"name\",    \"percentUsed\" : 5.962133916683182,    \"used\" : 6,    \"type\" : \"type\"  },  \"storeInfo\" : {    \"avail\" : 1,    \"percentUsedString\" : \"percentUsedString\",    \"size\" : 0,    \"name\" : \"name\",    \"percentUsed\" : 5.962133916683182,    \"used\" : 6,    \"type\" : \"type\"  }}", RepositoryInfo.class), HttpStatus.NOT_IMPLEMENTED);
                } catch (IOException e) {
                    log.error("Couldn't serialize response for content type application/json", e);
                    return new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR);
                }
            }
        } else {
            log.warn("ObjectMapper or HttpServletRequest not configured in default RepoinfoApi interface so no example is generated");
        }
        return new ResponseEntity<>(HttpStatus.NOT_IMPLEMENTED);
    }

}

==> laaws-repository-service-2.12.1-sources.jar: org/lockss/laaws/rs/api/RepoinfoApiDelegate.java <==
package org.lockss.laaws.rs.api;

import org.lockss.laaws.rs.model.RepositoryInfo;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.swagger.annotations.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.multipart.MultipartFile;
import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Optional;

/**
 * A delegate to be called by the {@link RepoinfoApiController}}.
 * Implement this interface with a {@link org.springframework.stereotype.Service} annotated class.
 */

public interface RepoinfoApiDelegate {

    Logger log = LoggerFactory.getLogger(RepoinfoApi.class);

    default Optional<ObjectMapper> getObjectMapper() {
        return Optional.empty();
    }

    default Optional<HttpServletRequest> getRequest() {
        return Optional.empty();
    }

    default Optional<String> getAcceptHeader() {
        return getRequest().map(r -> r.getHeader("Accept"));
    }

    /**
     * @see RepoinfoApi#getRepositoryInformation
     */
    default ResponseEntity<RepositoryInfo> getRepositoryInformation() {
        if(getObjectMapper().isPresent() && getAcceptHeader().isPresent()) {
            if (getAcceptHeader().get().contains("application/json")) {
                try {
                    return new ResponseEntity<>(getObjectMapper().get().readValue("{\"empty\": false}", RepositoryInfo.class), HttpStatus.NOT_IMPLEMENTED);
                } catch (IOException e) {
                    log.error("Couldn't serialize response for content type application/json", e);
                    return new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR);
                }
            }
        } else {
            log.warn("ObjectMapper or HttpServletRequest not configured in default RepoinfoApi interface so no example is generated");
        }
        return new ResponseEntity<>(HttpStatus.NOT_IMPLEMENTED);
    }

}
